@@ -261,6 +261,10 @@
       }
     }
   }
+  if ( ! is.null( beta <- canon.init$beta)) { # outer beta
+    lower$trBeta[names(beta)] <- -Inf
+    upper$trBeta[names(beta)] <- Inf
+  }
   ## names() to make sure the order of elements match; remove any extra stuff (which?... hmmm erroneous inclusion of some pars...) 
   return(list(lower=lower[names(init.optim)],upper=upper[names(init.optim)])) 
 }
